# autogenerated module
from typing import List, Optional, TYPE_CHECKING

from ._schema import dataclass, field, DictMixin

if TYPE_CHECKING:   # Fix for pycharm autocompletion https://youtrack.jetbrains.com/issue/PY-54560
    from dataclasses import dataclass, field



@dataclass
class Info(DictMixin):
    """Info contains versioning information. how we'll want to distribute that
      information.

      **parameters**

      * **buildDate** ``str`` - 
      * **compiler** ``str`` - 
      * **gitCommit** ``str`` - 
      * **gitTreeState** ``str`` - 
      * **gitVersion** ``str`` - 
      * **goVersion** ``str`` - 
      * **major** ``str`` - 
      * **minor** ``str`` - 
      * **platform** ``str`` - 
    """
    buildDate: 'str'
    compiler: 'str'
    gitCommit: 'str'
    gitTreeState: 'str'
    gitVersion: 'str'
    goVersion: 'str'
    major: 'str'
    minor: 'str'
    platform: 'str'


