# autogenerated module
from typing import ClassVar

from ..core import resource as res
from ..models import authorization_v1 as m_authorization_v1


class LocalSubjectAccessReview(res.NamespacedResource, m_authorization_v1.LocalSubjectAccessReview):
    """* **Extends**: ``models.authorization_v1.LocalSubjectAccessReview``
       * **Type**: Namespaced Resource
       * **Accepted client methods**: `create`
    """
    _api_info = res.ApiInfo(
        resource=res.ResourceDef('authorization.k8s.io', 'v1', 'LocalSubjectAccessReview'),
        plural='localsubjectaccessreviews',
        verbs=['post'],
    )


class SelfSubjectAccessReview(res.GlobalResource, m_authorization_v1.SelfSubjectAccessReview):
    """* **Extends**: ``models.authorization_v1.SelfSubjectAccessReview``
       * **Type**: Global Resource
       * **Accepted client methods**: `create`
    """
    _api_info = res.ApiInfo(
        resource=res.ResourceDef('authorization.k8s.io', 'v1', 'SelfSubjectAccessReview'),
        plural='selfsubjectaccessreviews',
        verbs=['post'],
    )


class SelfSubjectRulesReview(res.GlobalResource, m_authorization_v1.SelfSubjectRulesReview):
    """* **Extends**: ``models.authorization_v1.SelfSubjectRulesReview``
       * **Type**: Global Resource
       * **Accepted client methods**: `create`
    """
    _api_info = res.ApiInfo(
        resource=res.ResourceDef('authorization.k8s.io', 'v1', 'SelfSubjectRulesReview'),
        plural='selfsubjectrulesreviews',
        verbs=['post'],
    )


class SubjectAccessReview(res.GlobalResource, m_authorization_v1.SubjectAccessReview):
    """* **Extends**: ``models.authorization_v1.SubjectAccessReview``
       * **Type**: Global Resource
       * **Accepted client methods**: `create`
    """
    _api_info = res.ApiInfo(
        resource=res.ResourceDef('authorization.k8s.io', 'v1', 'SubjectAccessReview'),
        plural='subjectaccessreviews',
        verbs=['post'],
    )

